#include <LiquidCrystal.h>

const int FLEX_PIN = A0; // Pin connected to voltage divider output

// Measure the voltage at 5V and the actual resistance of your
// 47k resistor, and enter them below:
const float VCC = 5.03; // Measured voltage of Ardunio 5V line
const float R_DIV = 45800.0; // Measured resistance of 47.0k resistor

// Upload the code, then try to adjust these values to more
// accurately calculate bend degree.
const float STRAIGHT_RESISTANCE = 25000.00; // resistance when straight
const float BEND_RESISTANCE = 51906.66; // resistance at 90 deg

LiquidCrystal lcd(8,9,10,11,12,13);

void setup() 
{
  Serial.begin(9600);
  pinMode(FLEX_PIN, INPUT);
  lcd.clear();
  lcd.begin(16,2);
}

void loop() 
{
  int flexADC = 0;
  
  for(short i=0; i<20; i++)
  {
    flexADC += analogRead(FLEX_PIN);
    delay(10);
  }

  flexADC = flexADC/20;

  float flexV = flexADC * VCC / 1024.0;
  float flexR = R_DIV * (VCC / flexV - 1.0);
  Serial.println("Resistance: " + String(flexR) + " ohms");
  float angle = map(flexR, STRAIGHT_RESISTANCE, BEND_RESISTANCE, 0, 90.0);
  Serial.println("Bend: " + String(angle) + " degrees");
  Serial.println();
  lcd.clear();
  lcd.setCursor(0,0);
  lcd.print("R: " + String(flexR) + " ohms");
  lcd.setCursor(0,1);
  lcd.print("A: " + String(angle) + " degrees");
  
  delay(300);
}
